@@ -23,13 +23,20 @@
 
 #ifndef AKONADI_CALENDAR_DEPRECATED
 #  define AKONADI_CALENDAR_DEPRECATED __attribute__ ((__deprecated__))
-#  define AKONADI_CALENDAR_DEPRECATED_EXPORT AKONADI_CALENDAR_EXPORT __attribute__ ((__deprecated__))
-#  define AKONADI_CALENDAR_DEPRECATED_NO_EXPORT AKONADI_CALENDAR_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define AKONADI_CALENDAR_NO_DEPRECATED
+#ifndef AKONADI_CALENDAR_DEPRECATED_EXPORT
+#  define AKONADI_CALENDAR_DEPRECATED_EXPORT AKONADI_CALENDAR_EXPORT AKONADI_CALENDAR_DEPRECATED
 #endif
 
+#ifndef AKONADI_CALENDAR_DEPRECATED_NO_EXPORT
+#  define AKONADI_CALENDAR_DEPRECATED_NO_EXPORT AKONADI_CALENDAR_NO_EXPORT AKONADI_CALENDAR_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef AKONADI_CALENDAR_NO_DEPRECATED
+#    define AKONADI_CALENDAR_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* AKONADI_CALENDAR_EXPORT_H */
