@@ -23,13 +23,20 @@
 
 #ifndef AKONADI_CONTACT_DEPRECATED
 #  define AKONADI_CONTACT_DEPRECATED __attribute__ ((__deprecated__))
-#  define AKONADI_CONTACT_DEPRECATED_EXPORT AKONADI_CONTACT_EXPORT __attribute__ ((__deprecated__))
-#  define AKONADI_CONTACT_DEPRECATED_NO_EXPORT AKONADI_CONTACT_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define AKONADI_CONTACT_NO_DEPRECATED
+#ifndef AKONADI_CONTACT_DEPRECATED_EXPORT
+#  define AKONADI_CONTACT_DEPRECATED_EXPORT AKONADI_CONTACT_EXPORT AKONADI_CONTACT_DEPRECATED
+#endif
+
+#ifndef AKONADI_CONTACT_DEPRECATED_NO_EXPORT
+#  define AKONADI_CONTACT_DEPRECATED_NO_EXPORT AKONADI_CONTACT_NO_EXPORT AKONADI_CONTACT_DEPRECATED
+#endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef AKONADI_CONTACT_NO_DEPRECATED
+#    define AKONADI_CONTACT_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
