@@ -23,13 +23,20 @@
 
 #ifndef AKONADI_KABC_DEPRECATED
 #  define AKONADI_KABC_DEPRECATED __attribute__ ((__deprecated__))
-#  define AKONADI_KABC_DEPRECATED_EXPORT AKONADI_KABC_EXPORT __attribute__ ((__deprecated__))
-#  define AKONADI_KABC_DEPRECATED_NO_EXPORT AKONADI_KABC_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define AKONADI_KABC_NO_DEPRECATED
+#ifndef AKONADI_KABC_DEPRECATED_EXPORT
+#  define AKONADI_KABC_DEPRECATED_EXPORT AKONADI_KABC_EXPORT AKONADI_KABC_DEPRECATED
 #endif
 
+#ifndef AKONADI_KABC_DEPRECATED_NO_EXPORT
+#  define AKONADI_KABC_DEPRECATED_NO_EXPORT AKONADI_KABC_NO_EXPORT AKONADI_KABC_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef AKONADI_KABC_NO_DEPRECATED
+#    define AKONADI_KABC_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* AKONADI_KABC_EXPORT_H */
