@@ -33,9 +33,10 @@
 #  define AKONADI_KCAL_DEPRECATED_NO_EXPORT AKONADI_KCAL_NO_EXPORT AKONADI_KCAL_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define AKONADI_KCAL_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef AKONADI_KCAL_NO_DEPRECATED
+#    define AKONADI_KCAL_NO_DEPRECATED
+#  endif
 #endif
 
-#endif
+#endif /* AKONADI_KCAL_EXPORT_H */
