@@ -23,13 +23,20 @@
 
 #ifndef GPGMEPP_DEPRECATED
 #  define GPGMEPP_DEPRECATED __attribute__ ((__deprecated__))
-#  define GPGMEPP_DEPRECATED_EXPORT GPGMEPP_EXPORT __attribute__ ((__deprecated__))
-#  define GPGMEPP_DEPRECATED_NO_EXPORT GPGMEPP_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define GPGMEPP_NO_DEPRECATED
+#ifndef GPGMEPP_DEPRECATED_EXPORT
+#  define GPGMEPP_DEPRECATED_EXPORT GPGMEPP_EXPORT GPGMEPP_DEPRECATED
 #endif
 
+#ifndef GPGMEPP_DEPRECATED_NO_EXPORT
+#  define GPGMEPP_DEPRECATED_NO_EXPORT GPGMEPP_NO_EXPORT GPGMEPP_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef GPGMEPP_NO_DEPRECATED
+#    define GPGMEPP_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* GPGMEPP_EXPORT_H */
