@@ -23,13 +23,20 @@
 
 #ifndef KABC_DEPRECATED
 #  define KABC_DEPRECATED __attribute__ ((__deprecated__))
-#  define KABC_DEPRECATED_EXPORT KABC_EXPORT __attribute__ ((__deprecated__))
-#  define KABC_DEPRECATED_NO_EXPORT KABC_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KABC_NO_DEPRECATED
+#ifndef KABC_DEPRECATED_EXPORT
+#  define KABC_DEPRECATED_EXPORT KABC_EXPORT KABC_DEPRECATED
+#endif
+
+#ifndef KABC_DEPRECATED_NO_EXPORT
+#  define KABC_DEPRECATED_NO_EXPORT KABC_NO_EXPORT KABC_DEPRECATED
+#endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KABC_NO_DEPRECATED
+#    define KABC_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
