@@ -23,17 +23,24 @@
 
 #ifndef KALARMCAL_DEPRECATED
 #  define KALARMCAL_DEPRECATED __attribute__ ((__deprecated__))
-#  define KALARMCAL_DEPRECATED_EXPORT KALARMCAL_EXPORT __attribute__ ((__deprecated__))
-#  define KALARMCAL_DEPRECATED_NO_EXPORT KALARMCAL_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KALARMCAL_NO_DEPRECATED
+#ifndef KALARMCAL_DEPRECATED_EXPORT
+#  define KALARMCAL_DEPRECATED_EXPORT KALARMCAL_EXPORT KALARMCAL_DEPRECATED
 #endif
 
+#ifndef KALARMCAL_DEPRECATED_NO_EXPORT
+#  define KALARMCAL_DEPRECATED_NO_EXPORT KALARMCAL_NO_EXPORT KALARMCAL_DEPRECATED
 #endif
 
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KALARMCAL_NO_DEPRECATED
+#    define KALARMCAL_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* KALARMCAL_EXPORT_H */
+
 // This library was built to use Akonadi.
 // It must be rebuilt in order to use KResources.
 #ifdef KALARMCAL_USE_KRESOURCES
