@@ -23,13 +23,20 @@
 
 #ifndef KCAL_DEPRECATED
 #  define KCAL_DEPRECATED __attribute__ ((__deprecated__))
-#  define KCAL_DEPRECATED_EXPORT KCAL_EXPORT __attribute__ ((__deprecated__))
-#  define KCAL_DEPRECATED_NO_EXPORT KCAL_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KCAL_NO_DEPRECATED
+#ifndef KCAL_DEPRECATED_EXPORT
+#  define KCAL_DEPRECATED_EXPORT KCAL_EXPORT KCAL_DEPRECATED
 #endif
 
+#ifndef KCAL_DEPRECATED_NO_EXPORT
+#  define KCAL_DEPRECATED_NO_EXPORT KCAL_NO_EXPORT KCAL_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KCAL_NO_DEPRECATED
+#    define KCAL_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* KCAL_EXPORT_H */
