@@ -23,13 +23,20 @@
 
 #ifndef KCALCORE_DEPRECATED
 #  define KCALCORE_DEPRECATED __attribute__ ((__deprecated__))
-#  define KCALCORE_DEPRECATED_EXPORT KCALCORE_EXPORT __attribute__ ((__deprecated__))
-#  define KCALCORE_DEPRECATED_NO_EXPORT KCALCORE_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KCALCORE_NO_DEPRECATED
+#ifndef KCALCORE_DEPRECATED_EXPORT
+#  define KCALCORE_DEPRECATED_EXPORT KCALCORE_EXPORT KCALCORE_DEPRECATED
+#endif
+
+#ifndef KCALCORE_DEPRECATED_NO_EXPORT
+#  define KCALCORE_DEPRECATED_NO_EXPORT KCALCORE_NO_EXPORT KCALCORE_DEPRECATED
+#endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KCALCORE_NO_DEPRECATED
+#    define KCALCORE_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
