@@ -23,13 +23,20 @@
 
 #ifndef KCALUTILS_DEPRECATED
 #  define KCALUTILS_DEPRECATED __attribute__ ((__deprecated__))
-#  define KCALUTILS_DEPRECATED_EXPORT KCALUTILS_EXPORT __attribute__ ((__deprecated__))
-#  define KCALUTILS_DEPRECATED_NO_EXPORT KCALUTILS_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KCALUTILS_NO_DEPRECATED
+#ifndef KCALUTILS_DEPRECATED_EXPORT
+#  define KCALUTILS_DEPRECATED_EXPORT KCALUTILS_EXPORT KCALUTILS_DEPRECATED
+#endif
+
+#ifndef KCALUTILS_DEPRECATED_NO_EXPORT
+#  define KCALUTILS_DEPRECATED_NO_EXPORT KCALUTILS_NO_EXPORT KCALUTILS_DEPRECATED
+#endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KCALUTILS_NO_DEPRECATED
+#    define KCALUTILS_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
