@@ -23,8 +23,14 @@
 
 #ifndef KHOLIDAYS_DEPRECATED
 #  define KHOLIDAYS_DEPRECATED __attribute__ ((__deprecated__))
-#  define KHOLIDAYS_DEPRECATED_EXPORT KHOLIDAYS_EXPORT __attribute__ ((__deprecated__))
-#  define KHOLIDAYS_DEPRECATED_NO_EXPORT KHOLIDAYS_NO_EXPORT __attribute__ ((__deprecated__))
+#endif
+
+#ifndef KHOLIDAYS_DEPRECATED_EXPORT
+#  define KHOLIDAYS_DEPRECATED_EXPORT KHOLIDAYS_EXPORT KHOLIDAYS_DEPRECATED
+#endif
+
+#ifndef KHOLIDAYS_DEPRECATED_NO_EXPORT
+#  define KHOLIDAYS_DEPRECATED_NO_EXPORT KHOLIDAYS_NO_EXPORT KHOLIDAYS_DEPRECATED
 #endif
 
 #define DEFINE_NO_DEPRECATED 0
