@@ -23,13 +23,20 @@
 
 #ifndef KIMAP_DEPRECATED
 #  define KIMAP_DEPRECATED __attribute__ ((__deprecated__))
-#  define KIMAP_DEPRECATED_EXPORT KIMAP_EXPORT __attribute__ ((__deprecated__))
-#  define KIMAP_DEPRECATED_NO_EXPORT KIMAP_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KIMAP_NO_DEPRECATED
+#ifndef KIMAP_DEPRECATED_EXPORT
+#  define KIMAP_DEPRECATED_EXPORT KIMAP_EXPORT KIMAP_DEPRECATED
+#endif
+
+#ifndef KIMAP_DEPRECATED_NO_EXPORT
+#  define KIMAP_DEPRECATED_NO_EXPORT KIMAP_NO_EXPORT KIMAP_DEPRECATED
+#endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KIMAP_NO_DEPRECATED
+#    define KIMAP_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
