@@ -23,13 +23,20 @@
 
 #ifndef KMBOX_DEPRECATED
 #  define KMBOX_DEPRECATED __attribute__ ((__deprecated__))
-#  define KMBOX_DEPRECATED_EXPORT KMBOX_EXPORT __attribute__ ((__deprecated__))
-#  define KMBOX_DEPRECATED_NO_EXPORT KMBOX_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KMBOX_NO_DEPRECATED
+#ifndef KMBOX_DEPRECATED_EXPORT
+#  define KMBOX_DEPRECATED_EXPORT KMBOX_EXPORT KMBOX_DEPRECATED
 #endif
 
+#ifndef KMBOX_DEPRECATED_NO_EXPORT
+#  define KMBOX_DEPRECATED_NO_EXPORT KMBOX_NO_EXPORT KMBOX_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KMBOX_NO_DEPRECATED
+#    define KMBOX_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* KMBOX_EXPORT_H */
