@@ -23,13 +23,20 @@
 
 #ifndef KMIME_DEPRECATED
 #  define KMIME_DEPRECATED __attribute__ ((__deprecated__))
-#  define KMIME_DEPRECATED_EXPORT KMIME_EXPORT __attribute__ ((__deprecated__))
-#  define KMIME_DEPRECATED_NO_EXPORT KMIME_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KMIME_NO_DEPRECATED
+#ifndef KMIME_DEPRECATED_EXPORT
+#  define KMIME_DEPRECATED_EXPORT KMIME_EXPORT KMIME_DEPRECATED
 #endif
 
+#ifndef KMIME_DEPRECATED_NO_EXPORT
+#  define KMIME_DEPRECATED_NO_EXPORT KMIME_NO_EXPORT KMIME_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KMIME_NO_DEPRECATED
+#    define KMIME_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* KMIME_EXPORT_H */
