@@ -23,13 +23,20 @@
 
 #ifndef KONTACTINTERFACE_DEPRECATED
 #  define KONTACTINTERFACE_DEPRECATED __attribute__ ((__deprecated__))
-#  define KONTACTINTERFACE_DEPRECATED_EXPORT KONTACTINTERFACE_EXPORT __attribute__ ((__deprecated__))
-#  define KONTACTINTERFACE_DEPRECATED_NO_EXPORT KONTACTINTERFACE_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KONTACTINTERFACE_NO_DEPRECATED
+#ifndef KONTACTINTERFACE_DEPRECATED_EXPORT
+#  define KONTACTINTERFACE_DEPRECATED_EXPORT KONTACTINTERFACE_EXPORT KONTACTINTERFACE_DEPRECATED
 #endif
 
+#ifndef KONTACTINTERFACE_DEPRECATED_NO_EXPORT
+#  define KONTACTINTERFACE_DEPRECATED_NO_EXPORT KONTACTINTERFACE_NO_EXPORT KONTACTINTERFACE_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KONTACTINTERFACE_NO_DEPRECATED
+#    define KONTACTINTERFACE_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* KONTACTINTERFACE_EXPORT_H */
