@@ -23,8 +23,14 @@
 
 #ifndef KPIMIDENTITIES_DEPRECATED
 #  define KPIMIDENTITIES_DEPRECATED __attribute__ ((__deprecated__))
-#  define KPIMIDENTITIES_DEPRECATED_EXPORT KPIMIDENTITIES_EXPORT __attribute__ ((__deprecated__))
-#  define KPIMIDENTITIES_DEPRECATED_NO_EXPORT KPIMIDENTITIES_NO_EXPORT __attribute__ ((__deprecated__))
+#endif
+
+#ifndef KPIMIDENTITIES_DEPRECATED_EXPORT
+#  define KPIMIDENTITIES_DEPRECATED_EXPORT KPIMIDENTITIES_EXPORT KPIMIDENTITIES_DEPRECATED
+#endif
+
+#ifndef KPIMIDENTITIES_DEPRECATED_NO_EXPORT
+#  define KPIMIDENTITIES_DEPRECATED_NO_EXPORT KPIMIDENTITIES_NO_EXPORT KPIMIDENTITIES_DEPRECATED
 #endif
 
 #define DEFINE_NO_DEPRECATED 0
