@@ -23,13 +23,20 @@
 
 #ifndef KPIMTEXTEDIT_DEPRECATED
 #  define KPIMTEXTEDIT_DEPRECATED __attribute__ ((__deprecated__))
-#  define KPIMTEXTEDIT_DEPRECATED_EXPORT KPIMTEXTEDIT_EXPORT __attribute__ ((__deprecated__))
-#  define KPIMTEXTEDIT_DEPRECATED_NO_EXPORT KPIMTEXTEDIT_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KPIMTEXTEDIT_NO_DEPRECATED
+#ifndef KPIMTEXTEDIT_DEPRECATED_EXPORT
+#  define KPIMTEXTEDIT_DEPRECATED_EXPORT KPIMTEXTEDIT_EXPORT KPIMTEXTEDIT_DEPRECATED
 #endif
 
+#ifndef KPIMTEXTEDIT_DEPRECATED_NO_EXPORT
+#  define KPIMTEXTEDIT_DEPRECATED_NO_EXPORT KPIMTEXTEDIT_NO_EXPORT KPIMTEXTEDIT_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KPIMTEXTEDIT_NO_DEPRECATED
+#    define KPIMTEXTEDIT_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* KPIMTEXTEDIT_EXPORT_H */
