@@ -23,13 +23,20 @@
 
 #ifndef KPIMUTILS_DEPRECATED
 #  define KPIMUTILS_DEPRECATED __attribute__ ((__deprecated__))
-#  define KPIMUTILS_DEPRECATED_EXPORT KPIMUTILS_EXPORT __attribute__ ((__deprecated__))
-#  define KPIMUTILS_DEPRECATED_NO_EXPORT KPIMUTILS_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KPIMUTILS_NO_DEPRECATED
+#ifndef KPIMUTILS_DEPRECATED_EXPORT
+#  define KPIMUTILS_DEPRECATED_EXPORT KPIMUTILS_EXPORT KPIMUTILS_DEPRECATED
 #endif
 
+#ifndef KPIMUTILS_DEPRECATED_NO_EXPORT
+#  define KPIMUTILS_DEPRECATED_NO_EXPORT KPIMUTILS_NO_EXPORT KPIMUTILS_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KPIMUTILS_NO_DEPRECATED
+#    define KPIMUTILS_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* KPIMUTILS_EXPORT_H */
