@@ -23,13 +23,20 @@
 
 #ifndef KRESOURCES_DEPRECATED
 #  define KRESOURCES_DEPRECATED __attribute__ ((__deprecated__))
-#  define KRESOURCES_DEPRECATED_EXPORT KRESOURCES_EXPORT __attribute__ ((__deprecated__))
-#  define KRESOURCES_DEPRECATED_NO_EXPORT KRESOURCES_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KRESOURCES_NO_DEPRECATED
+#ifndef KRESOURCES_DEPRECATED_EXPORT
+#  define KRESOURCES_DEPRECATED_EXPORT KRESOURCES_EXPORT KRESOURCES_DEPRECATED
 #endif
 
+#ifndef KRESOURCES_DEPRECATED_NO_EXPORT
+#  define KRESOURCES_DEPRECATED_NO_EXPORT KRESOURCES_NO_EXPORT KRESOURCES_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KRESOURCES_NO_DEPRECATED
+#    define KRESOURCES_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* KRESOURCES_EXPORT_H */
