@@ -23,13 +23,20 @@
 
 #ifndef KTNEF_DEPRECATED
 #  define KTNEF_DEPRECATED __attribute__ ((__deprecated__))
-#  define KTNEF_DEPRECATED_EXPORT KTNEF_EXPORT __attribute__ ((__deprecated__))
-#  define KTNEF_DEPRECATED_NO_EXPORT KTNEF_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KTNEF_NO_DEPRECATED
+#ifndef KTNEF_DEPRECATED_EXPORT
+#  define KTNEF_DEPRECATED_EXPORT KTNEF_EXPORT KTNEF_DEPRECATED
 #endif
 
+#ifndef KTNEF_DEPRECATED_NO_EXPORT
+#  define KTNEF_DEPRECATED_NO_EXPORT KTNEF_NO_EXPORT KTNEF_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KTNEF_NO_DEPRECATED
+#    define KTNEF_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* KTNEF_EXPORT_H */
