@@ -23,13 +23,20 @@
 
 #ifndef KXMLRPCCLIENT_DEPRECATED
 #  define KXMLRPCCLIENT_DEPRECATED __attribute__ ((__deprecated__))
-#  define KXMLRPCCLIENT_DEPRECATED_EXPORT KXMLRPCCLIENT_EXPORT __attribute__ ((__deprecated__))
-#  define KXMLRPCCLIENT_DEPRECATED_NO_EXPORT KXMLRPCCLIENT_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KXMLRPCCLIENT_NO_DEPRECATED
+#ifndef KXMLRPCCLIENT_DEPRECATED_EXPORT
+#  define KXMLRPCCLIENT_DEPRECATED_EXPORT KXMLRPCCLIENT_EXPORT KXMLRPCCLIENT_DEPRECATED
 #endif
 
+#ifndef KXMLRPCCLIENT_DEPRECATED_NO_EXPORT
+#  define KXMLRPCCLIENT_DEPRECATED_NO_EXPORT KXMLRPCCLIENT_NO_EXPORT KXMLRPCCLIENT_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KXMLRPCCLIENT_NO_DEPRECATED
+#    define KXMLRPCCLIENT_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* KXMLRPCCLIENT_EXPORT_H */
