@@ -23,13 +23,20 @@
 
 #ifndef MAILTRANSPORT_DEPRECATED
 #  define MAILTRANSPORT_DEPRECATED __attribute__ ((__deprecated__))
-#  define MAILTRANSPORT_DEPRECATED_EXPORT MAILTRANSPORT_EXPORT __attribute__ ((__deprecated__))
-#  define MAILTRANSPORT_DEPRECATED_NO_EXPORT MAILTRANSPORT_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define MAILTRANSPORT_NO_DEPRECATED
+#ifndef MAILTRANSPORT_DEPRECATED_EXPORT
+#  define MAILTRANSPORT_DEPRECATED_EXPORT MAILTRANSPORT_EXPORT MAILTRANSPORT_DEPRECATED
 #endif
 
+#ifndef MAILTRANSPORT_DEPRECATED_NO_EXPORT
+#  define MAILTRANSPORT_DEPRECATED_NO_EXPORT MAILTRANSPORT_NO_EXPORT MAILTRANSPORT_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef MAILTRANSPORT_NO_DEPRECATED
+#    define MAILTRANSPORT_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* MAILTRANSPORT_EXPORT_H */
