@@ -23,13 +23,20 @@
 
 #ifndef MICROBLOG_DEPRECATED
 #  define MICROBLOG_DEPRECATED __attribute__ ((__deprecated__))
-#  define MICROBLOG_DEPRECATED_EXPORT MICROBLOG_EXPORT __attribute__ ((__deprecated__))
-#  define MICROBLOG_DEPRECATED_NO_EXPORT MICROBLOG_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define MICROBLOG_NO_DEPRECATED
+#ifndef MICROBLOG_DEPRECATED_EXPORT
+#  define MICROBLOG_DEPRECATED_EXPORT MICROBLOG_EXPORT MICROBLOG_DEPRECATED
 #endif
 
+#ifndef MICROBLOG_DEPRECATED_NO_EXPORT
+#  define MICROBLOG_DEPRECATED_NO_EXPORT MICROBLOG_NO_EXPORT MICROBLOG_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef MICROBLOG_NO_DEPRECATED
+#    define MICROBLOG_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* MICROBLOG_EXPORT_H */
