@@ -23,13 +23,20 @@
 
 #ifndef QGPGME_DEPRECATED
 #  define QGPGME_DEPRECATED __attribute__ ((__deprecated__))
-#  define QGPGME_DEPRECATED_EXPORT QGPGME_EXPORT __attribute__ ((__deprecated__))
-#  define QGPGME_DEPRECATED_NO_EXPORT QGPGME_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define QGPGME_NO_DEPRECATED
+#ifndef QGPGME_DEPRECATED_EXPORT
+#  define QGPGME_DEPRECATED_EXPORT QGPGME_EXPORT QGPGME_DEPRECATED
+#endif
+
+#ifndef QGPGME_DEPRECATED_NO_EXPORT
+#  define QGPGME_DEPRECATED_NO_EXPORT QGPGME_NO_EXPORT QGPGME_DEPRECATED
+#endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef QGPGME_NO_DEPRECATED
+#    define QGPGME_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
