@@ -23,8 +23,14 @@
 
 #ifndef SYNDICATION_DEPRECATED
 #  define SYNDICATION_DEPRECATED __attribute__ ((__deprecated__))
-#  define SYNDICATION_DEPRECATED_EXPORT SYNDICATION_EXPORT __attribute__ ((__deprecated__))
-#  define SYNDICATION_DEPRECATED_NO_EXPORT SYNDICATION_NO_EXPORT __attribute__ ((__deprecated__))
+#endif
+
+#ifndef SYNDICATION_DEPRECATED_EXPORT
+#  define SYNDICATION_DEPRECATED_EXPORT SYNDICATION_EXPORT SYNDICATION_DEPRECATED
+#endif
+
+#ifndef SYNDICATION_DEPRECATED_NO_EXPORT
+#  define SYNDICATION_DEPRECATED_NO_EXPORT SYNDICATION_NO_EXPORT SYNDICATION_DEPRECATED
 #endif
 
 #define DEFINE_NO_DEPRECATED 0
